@@ -185,12 +185,12 @@ Other:
 
 
 
-    def save(self, fname ):
+    def save(self, fname, transparent=False ):
         """ Save figure to file.
             fname : filename to save.
                     File type automatically determined from extension.
         """
-        self.fig.savefig( fname, bbox_extra_artists=self.ax.get_default_bbox_extra_artists(), bbox_inches='tight' )
+        self.fig.savefig( fname, bbox_extra_artists=self.ax.get_default_bbox_extra_artists(), bbox_inches='tight', transparent=transparent )
 
 
     # Functions to help define specific elements
